# eric7.WebBrowser.QtHelp

Package containing the interface to QtHelp.

### Modules

HelpDocsInstaller | Module implementing a thread class populating and updating the QtHelp documentation database.
HelpIndexWidget | Module implementing a window for showing the QtHelp index.
HelpSearchWidget | Module implementing a window for showing the QtHelp index.
HelpTocWidget | Module implementing a window for showing the QtHelp TOC.
HelpTopicDialog | Module implementing a dialog to select a help topic to display.
QtHelpDocumentationConfigurationDialog | Module implementing a dialog to manage the QtHelp documentation database.
QtHelpDocumentationSelectionDialog | Module implementing a dialog to select QtHelp documentation sets to be installed.
QtHelpDocumentationSettings | Module implementing a class to store the QtHelp documentation settings before being applied to the help engine.
QtHelpDocumentationSettingsWidget | Module implementing a widget to manage the QtHelp documentation settings.